pub struct TcpClient<'d, D: Driver, const N: usize, const TX_SZ: usize = 1024, const RX_SZ: usize = 1024> { /* private fields */ }Expand description
TCP client connection pool compatible with embedded-nal-async traits.
The pool is capable of managing up to N concurrent connections with tx and rx buffers according to TX_SZ and RX_SZ.
Implementations